@@ -17,6 +17,13 @@ DEFAULT_TRIGGER = "runverify"
 DEFAULT_PREVENT_BUILD_TOPIC = "NOCI"
 RE_CHANGEID = re.compile(r"change-id:\s+(?P<changeid>I[a-z0-9]+)", re.IGNORECASE | re.MULTILINE)
 
+def isFileInRepo(repo, path_to_file):
+    rsub = repo.head.commit.tree
+    for element in rsub.traverse():
+        if element.path == path_to_file:
+            return True
+    return False
+
 
 @log_decorator
 def prepare(rest, git_repo, args, gerrit_config):
@@ -501,11 +508,11 @@ def _get_payload(git_repo, payload_json, path_prefixes, robot_id, robot_run_id):
     comments = payload["comments"].copy()
     payload["robot_comments"] = {}
     for key in comments:
-        if not key.startswith(git_repo.working_dir): ## TODO: if compiledb doesnt have absolute paths, this most likely will fail, fix later
+        new_key = trim_prefixes(key, prefixes)
+        if not isFileInRepo(git_repo, new_key):
             LOGGER.debug(f"File {key} contains issues reported by static analysis but its not part of the git repository at {git_repo.working_dir} - Skipping!")
             continue
 
-        new_key = trim_prefixes(key, prefixes)
         for item in comments[key]:
             item["robot_id"] = "clang-tidy"
             res = regex.match(item["message"])
@@ -543,7 +550,7 @@ def review(rest, git_repo, args, gerrit_config):
     rev = get_rev(change_details)
     payload = _get_payload(git_repo, args.payload, args.path_prefixes, args.robot_id, args.robot_run_id)
     payload["omit_duplicate_comments"] = True
-    payload["notify"] = "OWNER"
+    payload["notify"] = "NONE"
 
     try:
         return rest.post(f"/changes/{args.changeid}/revisions/{rev}/review", data=payload)
